function [fig_out, axes_out, plot_out] = dd(w,varargin)
%----------------help for gtk dp errorbar and marker plot------------------
%
% purpose: plot errorbars, markers and line through the data
% 
% Function Syntax: 
% [ figureHandle_,axesHandle_,plotHandle_] = 
% DD(w,[property_name,property_value]) or
% DD(w,xlo,xhi) or
% DD(w,xlo,xhi,ylo,yhi)
%
% Output: figure,axes and plot handle matrix - figure/axes/plotHandle_(:,1)
% are handles to the errorbars, figure/axes/plotHandle_(:,2) are handles to
% the markers, figure/axes/plotHandle_(:,3) are handles to the lines
%
% Input: 1d dataset object and other control parameters (name value pairs)
% you can also give axis limit for x and y 
%
% Purpose: plot the data according to values and control properties (for
% figure, axes and plot)
%
% Example: 
% DD(w) --> default structure plot
% DD(w,'Color','red') --> override default structure values 
% DD(w,'default','my_struct','Color','red') --> override values 
% DD(w,'default','my_struct') --> from structure
% DD(w,10,20)
% DD(w,10,20,0,200)
%--------------------------------------------------------------------------

if strcmp(class(w),'IXTdataset_2d')
    w=ixf_twod_to_oned(w);
end


tot = numel(varargin);
if ( tot == 2)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'d','xlim',[varargin{1},varargin{2}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'d',varargin{:});
    end
elseif (tot == 4)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'d','xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'d',varargin{:});
    end    
else
    [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'d',varargin{:});    
end

if nargout > 0
    fig_out = figureHandle_;
    axes_out = axesHandle_;
    plot_out = plotHandle_;
end


