function [fig_out, axes_out, plot_out] = mp(w,varargin)
%------help for gtk multiplot command mp-----------------------------------
% multiplot an array of dataset_1d or single dataset_2d
%
% Function Syntax: figure_handle = MP(w,['name',value,'tag',value,options])
%
% Output: figure, axes and plot handles
% Input: 1d dataset object, control parameter like name and tag can be
% given, options can be given such as afontcolor or title.
%
% Examples: 
%
% MP(w) 
% the above example multiplot spectrum(w) data
%
% MP(w,'name','tobie') 
% the above example multiplot spectrum(w) data with name as tobie
%
% MP(w,'name','tobie','tag','1d') 
% the above example multiplot spectrum(w) data with name as tobie and tag as
% 1d
%
%--------------------------------------------------------------------------

tot = numel(varargin);
if isa(w,'IXTdataset_2d')
    [xlab,ylab,zlab]=make_label(w);
    w=ixf_twod_to_oned(w);
elseif isa(w,'IXTdataset_1d');
% ylabel cannot be determined from a dataset_1d, so is forced to be
% Spectrum Number, use the first dataset_1d in the array
[xlab,zlab]=make_label(w(1));
    ylab = 'Spectrum Number';
else
    error('ERROR: Invalid input to mp function, must be an IXTdataset_1d or IXTdataset_2d')
end


if ( tot == 2)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_multiplot(w,'xlim',[varargin{1},varargin{2}],'xlabel',xlab, 'ylabel',ylab,'zlabel',zlab);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_multiplot(w,'xlabel',xlab, 'ylabel',ylab,'zlabel',zlab,varargin{:});
    end
elseif (tot == 4)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_multiplot(w,'xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}],'xlabel',xlab, 'ylabel',ylab,'zlabel',zlab);
    else 
        [figureHandle_,axesHandle_,plotHandle_] = uib_multiplot(w,'xlabel',xlab, 'ylabel',ylab,'zlabel',zlab, varargin{:});
    end    
elseif (tot==6)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4})&& isnumeric(varargin{5}) && isnumeric(varargin{6}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_multiplot(w,'xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}],'zlim',[varargin{5},varargin{6}],'xlabel',xlab, 'ylabel',ylab,'zlabel',zlab);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_multiplot(w,'xlabel',xlab, 'ylabel',ylab,'zlabel',zlab,varargin{:});
    end
else
    [figureHandle_,axesHandle_,plotHandle_] = uib_multiplot(w,'xlabel',xlab, 'ylabel',ylab,'zlabel',zlab,varargin{:});    
end

if nargout > 0
    fig_out = figureHandle_;
    axes_out = axesHandle_;
    plot_out = plotHandle_;
end

