function [fig_out, axes_out, plot_out] = dh(w,varargin)
%--------help for gtk histogram plot command dh----------------------------
% Function Syntax: 
% [figureHandle_,axesHandle_,plotHandle_] = 
% DH(w,[property_name,property_value]) or DH(w,xlo,xhi) or
% DH(w,xlo,xhi) or
% DH(w,xlo,xhi,ylo,yhi)
% 
% Output: figure,axes and plot handle
% Input: 1d dataset object and other control parameters (name value pairs)
%  you can also give axis limit for x and y 
% 
% Purpose: plot the data according to values and control properties (for
% figure, axes and plot)
% 
% Example: 
% DH(w) --> default structure plot
% DH(w,'Color','red') --> override default structure values 
% DH(w,'default','my_struct','Color','red') --> override values 
% DH(w,'default','my_struct') --> from structure
% DH(w,10,20)
% DH(w,10,20,0,200)
%--------------------------------------------------------------------------


if strcmp(class(w),'IXTdataset_2d')
    w=ixf_twod_to_oned(w);
end

tot = numel(varargin);

if ( tot == 2)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'h','xlim',[varargin{1},varargin{2}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'h',varargin{:});
    end
elseif (tot == 4)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'h','xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'h',varargin{:});
    end    
else
    [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'h',varargin{:});    
end

if nargout > 0
    fig_out = figureHandle_;
    axes_out = axesHandle_;
    plot_out = plotHandle_;
end

