function [fig_out, axes_out, plot_out] = dp(w,varargin)
%----------------help for gtk dp errorbar and marker plot command----------
%
% purpose: plot markers and errorbars.
% 
% Function Syntax: 
% [ figureHandle_,axesHandle_,plotHandle_] = 
% DP(w,[property_name,property_value]) or
% DP(w,xlo,xhi) or
% DP(w,xlo,xhi,ylo,yhi)
%
% Output: figure,axes and plot handle matrix - figure/axes/plotHandle_(:,1)
% are handles to the errorbars, figure/axes/plotHandle_(:,2) are handles to
% the markers
%
% Input: 1d dataset object and other control parameters (name value pairs)
% list of control propertie names
% >>IXG_ST_DEFAULT.figure
% >>IXG_ST_DEFAULT.plot
% >>IXG_ST_DEFAULT.axes
% you can also give axis limit for x and y 
% Purpose: plot the data according to values and control properties (for
% figure, axes and plot)
%
% Examples: 
% DP(w) --> default structure plot
% DP(w,'Color','red') --> override default structure values 
% DP(w,'default','my_struct','Color','red') --> override values 
% DP(w,'default','my_struct') --> from structure
% DP(w,10,20)
% DP(w,10,20,0,200)
%--------------------------------------------------------------------------



if strcmp(class(w),'IXTdataset_2d')
    w=ixf_twod_to_oned(w);
end


tot = numel(varargin);
if ( tot == 2)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'p','xlim',[varargin{1},varargin{2}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'p',varargin{:});
    end
elseif (tot == 4)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'p','xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'p',varargin{:});
    end    
else
    [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'p',varargin{:});    
end

if nargout > 0
    fig_out = figureHandle_;
    axes_out = axesHandle_;
    plot_out = plotHandle_;
end
